aboutsummaryrefslogtreecommitdiffstats
path: root/calendar/gui/e-cal-list-view.h
diff options
context:
space:
mode:
authorJP Rosevear <jpr@src.gnome.org>2003-11-07 13:52:24 +0800
committerJP Rosevear <jpr@src.gnome.org>2003-11-07 13:52:24 +0800
commit200606f92810d3de322e5ee96f8326e1a656f8bb (patch)
treeda0dc27f5311128dcb6e7eb6400931e45743372e /calendar/gui/e-cal-list-view.h
parente5472b4cc9a4bb80b89437a16f8b77943ea35555 (diff)
downloadgsoc2013-evolution-200606f92810d3de322e5ee96f8326e1a656f8bb.tar
gsoc2013-evolution-200606f92810d3de322e5ee96f8326e1a656f8bb.tar.gz
gsoc2013-evolution-200606f92810d3de322e5ee96f8326e1a656f8bb.tar.bz2
gsoc2013-evolution-200606f92810d3de322e5ee96f8326e1a656f8bb.tar.lz
gsoc2013-evolution-200606f92810d3de322e5ee96f8326e1a656f8bb.tar.xz
gsoc2013-evolution-200606f92810d3de322e5ee96f8326e1a656f8bb.tar.zst
gsoc2013-evolution-200606f92810d3de322e5ee96f8326e1a656f8bb.zip
Various changes to merge in evolution-data-server reliance.
svn path=/trunk/; revision=23206
Diffstat (limited to 'calendar/gui/e-cal-list-view.h')
-rw-r--r--calendar/gui/e-cal-list-view.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/calendar/gui/e-cal-list-view.h b/calendar/gui/e-cal-list-view.h
index edf2e843e2..37c0e9675b 100644
--- a/calendar/gui/e-cal-list-view.h
+++ b/calendar/gui/e-cal-list-view.h
@@ -50,7 +50,7 @@ typedef struct _ECalListViewClass ECalListViewClass;
struct _ECalListView
{
- ECalView cal_view;
+ ECalendarView cal_view;
/* The main display table */
ETableScrolled *table_scrolled;
@@ -59,7 +59,7 @@ struct _ECalListView
gchar *table_state_path;
/* S-expression for query and the query object */
- CalQuery *query;
+ ECalView *query;
/* The default category for new events */
gchar *default_category;
@@ -67,8 +67,8 @@ struct _ECalListView
/* Date editing cell */
ECellDateEdit *dates_cell;
- /* The last ECalViewEvent we returned from e_cal_list_view_get_selected_events(), to be freed */
- ECalViewEvent *cursor_event;
+ /* The last ECalendarViewEvent we returned from e_cal_list_view_get_selected_events(), to be freed */
+ ECalendarViewEvent *cursor_event;
/* Idle handler ID for setting a new ETableModel */
gint set_table_id;
@@ -76,7 +76,7 @@ struct _ECalListView
struct _ECalListViewClass
{
- ECalViewClass parent_class;
+ ECalendarViewClass parent_class;
};